package jp.ac.takushoku_u.cs;

/**
* NotElementException饹¸ߤʤǤꤷȤ򼨤˥ޤ
* @version 1.2
* @author  ͵(Kasajima Hiroshi)
*/
/*
* ǽ 2004ǯ1209
*/

public class NotElementException extends NotIndexException{

/**
* åʤ NotElementException ۤޤ
*/
	public NotElementException(){
		super();
	}
	
/**
* ꤷܺ٥å NotElementException ۤޤ
* @param s ܺ٥å
*/
	public NotElementException(String s){
		super(s);
	}
}